@@ -5,6 +5,7 @@
 #include <config.h>
 #include <panel-applet.h>
 #include <libgnomeui/gnome-help.h>
+#include <gucharmap/gucharmap.h>
 #include "charpick.h"
 
 
@@ -387,6 +388,30 @@ chooser_button_clicked (GtkButton *button, charpick_data *curr_data)
 	}				    
 }
 
+/* Force the button not to have any focus padding and let the focus
+   indication be drawn on the label itself when space is tight. Taken from the clock applet.
+   FIXME : This is an Evil Hack and should be fixed when the focus padding can be overridden at the gtk+ level */
+
+static inline void force_no_focus_padding (GtkWidget *widget)
+{
+  gboolean first_time=TRUE;
+
+  if (first_time) {
+    gtk_rc_parse_string ("\n"
+			 "   style \"charpick-applet-button-style\"\n"
+			 "   {\n"
+			 "      GtkWidget::focus-line-width=0\n"
+			 "      GtkWidget::focus-padding=0\n"
+			 "   }\n"
+			 "\n"
+			 "    widget \"*.charpick-applet-button\" style \"charpick-applet-button-style\"\n"
+			 "\n");
+    first_time = FALSE;
+  }
+
+  gtk_widget_set_name (widget, "charpick-applet-button");
+}
+
 /* creates table of buttons, sets up their callbacks, and packs the table in
    the event box */
 
@@ -435,6 +460,8 @@ build_table(charpick_data *p_curr_data)
   }
   gtk_container_add (GTK_CONTAINER (button), arrow);
   gtk_button_set_relief(GTK_BUTTON(button), GTK_RELIEF_NONE);
+  /* FIXME : evil hack (see force_no_focus_padding) */
+  force_no_focus_padding (button);
   gtk_box_pack_start (GTK_BOX (box), button, TRUE, TRUE, 0);
   g_signal_connect (G_OBJECT (button), "clicked",
                             G_CALLBACK (chooser_button_clicked), p_curr_data);
@@ -447,17 +474,27 @@ build_table(charpick_data *p_curr_data)
     gint num;
     GtkRequisition req;
     gchar atk_desc[50];
+    gchar *name;
     
     g_utf8_strncpy (label, charlist, 1);
     charlist = g_utf8_next_char (charlist);
+
+    /* TRANSLATOR: This sentance reads something like 'Insert "PILCROW SIGN"'
+     *             hopefully, the name of the unicode character has already
+     *             been translated.
+     */
+    name = g_strdup_printf (_("Insert \"%s\""),
+		    gucharmap_get_unicode_name (g_utf8_get_char (label)));
    
     toggle_button[i] = gtk_toggle_button_new_with_label (label);
     sprintf(atk_desc, _("insert special character %s"), label);
     set_atk_name_description (toggle_button[i], NULL, atk_desc);
     gtk_widget_show (toggle_button[i]);
     gtk_button_set_relief(GTK_BUTTON(toggle_button[i]), GTK_RELIEF_NONE);
-    gtk_tooltips_set_tip (tooltips, toggle_button[i], 
-                      _("Insert special characters"), NULL);
+    /* FIXME : evil hack (see force_no_focus_padding) */
+    force_no_focus_padding (toggle_button[i]);
+    gtk_tooltips_set_tip (tooltips, toggle_button[i], name, NULL);
+    g_free (name);
                       
     gtk_widget_size_request (toggle_button[i], &req);
     
@@ -571,16 +608,9 @@ about (BonoboUIComponent *uic,
 	return;
   }
   
-  file = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP,
-				    "charpick.png", FALSE, NULL);
-  pixbuf = gdk_pixbuf_new_from_file (file, &error);
-  g_free (file);
+  pixbuf = gtk_icon_theme_load_icon (gtk_icon_theme_get_default (),
+		  "charpick", 48, 0, NULL);
    
-  if (error) {
-	g_warning (G_STRLOC ": cannot open %s: %s", file, error->message);
-	g_error_free (error);
-  }
-  
   curr_data->about_dialog = gnome_about_new (_("Character Palette"),
 					     VERSION,
 					     _("Copyright (C) 1998"),
@@ -747,7 +777,7 @@ charpicker_applet_fill (PanelApplet *applet)
   GList *list;
   gchar *string;
   
-  gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/charpick.png");
+  gtk_window_set_default_icon_name ("charpick");
   
   panel_applet_add_preferences (applet, "/schemas/apps/charpick/prefs", NULL);
   panel_applet_set_flags (applet, PANEL_APPLET_EXPAND_MINOR);
