@@ -1,4 +1,4 @@
-/* $Id: gweather-dialog.c,v 1.45 2004/08/15 14:10:10 davyd Exp $ */
+/* $Id: gweather-dialog.c,v 1.47 2004/10/22 14:10:36 davyd Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -26,6 +26,77 @@
 #include "gweather-pref.h"
 #include "gweather-dialog.h"
 
+static void gweather_dialog_save_geometry (GWeatherApplet *gw_applet)
+{
+	GtkWidget *window;
+	int w, h, x, y;
+
+	window = gw_applet->gweather_dialog;
+
+	gtk_window_get_position (GTK_WINDOW (window), &x, &y);
+	gtk_window_get_size (GTK_WINDOW (window), &w, &h);
+
+	g_message ("gweather: saving spatial window location: %dx%d+%d+%d",
+			w, h, x, y);
+
+	panel_applet_gconf_set_int (gw_applet->applet,
+			"dialog_width", w, NULL);
+	panel_applet_gconf_set_int (gw_applet->applet,
+			"dialog_height", h, NULL);
+	panel_applet_gconf_set_int (gw_applet->applet,
+			"dialog_x", x, NULL);
+	panel_applet_gconf_set_int (gw_applet->applet,
+			"dialog_y", y, NULL);
+}
+
+static void gweather_dialog_load_geometry (GWeatherApplet *gw_applet)
+{
+	GtkWidget *window;
+	int w, h, x, y;
+	GError *error;
+
+	window = gw_applet->gweather_dialog;
+	error = NULL;
+
+	w = panel_applet_gconf_get_int (gw_applet->applet,
+			"dialog_width", &error);
+	if (error)
+	{
+		g_message ("gweather: no spatial information available");
+		g_error_free (error);
+		return;
+	}
+	h = panel_applet_gconf_get_int (gw_applet->applet,
+			"dialog_height", &error);
+	if (error)
+	{
+		g_message ("gweather: no spatial information available");
+		g_error_free (error);
+		return;
+	}
+	x = panel_applet_gconf_get_int (gw_applet->applet,
+			"dialog_x", &error);
+	if (error)
+	{
+		g_message ("gweather: no spatial information available");
+		g_error_free (error);
+		return;
+	}
+	y = panel_applet_gconf_get_int (gw_applet->applet,
+			"dialog_y", &error);
+	if (error)
+	{
+		g_message ("gweather: no spatial information available");
+		g_error_free (error);
+		return;
+	}
+	
+	g_message ("gweather: got spatial window location: %dx%d+%d+%d",
+			w, h, x, y);
+
+	gtk_window_resize (GTK_WINDOW (window), w, h);
+	gtk_window_move (GTK_WINDOW (window), x, y);
+}
 
 static void response_cb (GtkDialog *dialog, gint id, gpointer data)
 {
@@ -38,7 +109,7 @@ static void response_cb (GtkDialog *dialog, gint id, gpointer data)
 
 	return;
     }
-    
+
     gweather_dialog_close(gw_applet);
     return;
 }
@@ -99,6 +170,7 @@ void gweather_dialog_create (GWeatherApplet *gw_applet)
   gtk_window_set_screen (GTK_WINDOW (gw_applet->gweather_dialog),
 			 gtk_widget_get_screen (GTK_WIDGET (gw_applet->applet)));
   gtk_window_set_policy (GTK_WINDOW (gw_applet->gweather_dialog), FALSE, FALSE, FALSE);
+  gweather_dialog_load_geometry (gw_applet);
   
   weather_vbox = GTK_DIALOG (gw_applet->gweather_dialog)->vbox;
   gtk_widget_show (weather_vbox);
@@ -213,6 +285,7 @@ void gweather_dialog_create (GWeatherApplet *gw_applet)
   gtk_table_attach (GTK_TABLE (cond_table), gw_applet->cond_location, 1, 2, 0, 1,
                     (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                     (GtkAttachOptions) (0), 0, 0);
+  gtk_label_set_selectable (GTK_LABEL (gw_applet->cond_location), TRUE);
   gtk_label_set_justify (GTK_LABEL (gw_applet->cond_location), GTK_JUSTIFY_LEFT);
   gtk_misc_set_alignment (GTK_MISC (gw_applet->cond_location), 0, 0.5);
 
@@ -221,6 +294,7 @@ void gweather_dialog_create (GWeatherApplet *gw_applet)
   gtk_table_attach (GTK_TABLE (cond_table), gw_applet->cond_update, 1, 2, 1, 2,
                     (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                     (GtkAttachOptions) (0), 0, 0);
+  gtk_label_set_selectable (GTK_LABEL (gw_applet->cond_update), TRUE);
   gtk_label_set_justify (GTK_LABEL (gw_applet->cond_update), GTK_JUSTIFY_LEFT);
   gtk_misc_set_alignment (GTK_MISC (gw_applet->cond_update), 0, 0.5);
 
@@ -229,6 +303,7 @@ void gweather_dialog_create (GWeatherApplet *gw_applet)
   gtk_table_attach (GTK_TABLE (cond_table), gw_applet->cond_cond, 1, 2, 2, 3,
                     (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                     (GtkAttachOptions) (0), 0, 0);
+  gtk_label_set_selectable (GTK_LABEL (gw_applet->cond_cond), TRUE);
   gtk_label_set_justify (GTK_LABEL (gw_applet->cond_cond), GTK_JUSTIFY_LEFT);
   gtk_misc_set_alignment (GTK_MISC (gw_applet->cond_cond), 0, 0.5);
 
@@ -237,6 +312,7 @@ void gweather_dialog_create (GWeatherApplet *gw_applet)
   gtk_table_attach (GTK_TABLE (cond_table), gw_applet->cond_sky, 1, 2, 3, 4,
                     (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                     (GtkAttachOptions) (0), 0, 0);
+  gtk_label_set_selectable (GTK_LABEL (gw_applet->cond_sky), TRUE);
   gtk_label_set_justify (GTK_LABEL (gw_applet->cond_sky), GTK_JUSTIFY_LEFT);
   gtk_misc_set_alignment (GTK_MISC (gw_applet->cond_sky), 0, 0.5);
 
@@ -245,6 +321,7 @@ void gweather_dialog_create (GWeatherApplet *gw_applet)
   gtk_table_attach (GTK_TABLE (cond_table), gw_applet->cond_temp, 1, 2, 4, 5,
                     (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                     (GtkAttachOptions) (0), 0, 0);
+  gtk_label_set_selectable (GTK_LABEL (gw_applet->cond_temp), TRUE);
   gtk_label_set_justify (GTK_LABEL (gw_applet->cond_temp), GTK_JUSTIFY_LEFT);
   gtk_misc_set_alignment (GTK_MISC (gw_applet->cond_temp), 0, 0.5);
 
@@ -253,6 +330,7 @@ void gweather_dialog_create (GWeatherApplet *gw_applet)
   gtk_table_attach (GTK_TABLE (cond_table), gw_applet->cond_apparent, 1, 2, 5, 6,
                     (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                     (GtkAttachOptions) (0), 0, 0);
+  gtk_label_set_selectable (GTK_LABEL (gw_applet->cond_apparent), TRUE);
   gtk_label_set_justify (GTK_LABEL (gw_applet->cond_apparent), GTK_JUSTIFY_LEFT);
   gtk_misc_set_alignment (GTK_MISC (gw_applet->cond_apparent), 0, 0.5);
 
@@ -261,6 +339,7 @@ void gweather_dialog_create (GWeatherApplet *gw_applet)
   gtk_table_attach (GTK_TABLE (cond_table), gw_applet->cond_dew, 1, 2, 6, 7,
                     (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                     (GtkAttachOptions) (0), 0, 0);
+  gtk_label_set_selectable (GTK_LABEL (gw_applet->cond_dew), TRUE);
   gtk_label_set_justify (GTK_LABEL (gw_applet->cond_dew), GTK_JUSTIFY_LEFT);
   gtk_misc_set_alignment (GTK_MISC (gw_applet->cond_dew), 0, 0.5);
 
@@ -269,6 +348,7 @@ void gweather_dialog_create (GWeatherApplet *gw_applet)
   gtk_table_attach (GTK_TABLE (cond_table), gw_applet->cond_humidity, 1, 2, 7, 8,
                     (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                     (GtkAttachOptions) (0), 0, 0);
+  gtk_label_set_selectable (GTK_LABEL (gw_applet->cond_humidity), TRUE);
   gtk_label_set_justify (GTK_LABEL (gw_applet->cond_humidity), GTK_JUSTIFY_LEFT);
   gtk_misc_set_alignment (GTK_MISC (gw_applet->cond_humidity), 0, 0.5);
 
@@ -277,6 +357,7 @@ void gweather_dialog_create (GWeatherApplet *gw_applet)
   gtk_table_attach (GTK_TABLE (cond_table), gw_applet->cond_wind, 1, 2, 8, 9,
                     (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                     (GtkAttachOptions) (0), 0, 0);
+  gtk_label_set_selectable (GTK_LABEL (gw_applet->cond_wind), TRUE);
   gtk_label_set_justify (GTK_LABEL (gw_applet->cond_wind), GTK_JUSTIFY_LEFT);
   gtk_misc_set_alignment (GTK_MISC (gw_applet->cond_wind), 0, 0.5);
 
@@ -285,6 +366,7 @@ void gweather_dialog_create (GWeatherApplet *gw_applet)
   gtk_table_attach (GTK_TABLE (cond_table), gw_applet->cond_pressure, 1, 2, 9, 10,
                     (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                     (GtkAttachOptions) (0), 0, 0);
+  gtk_label_set_selectable (GTK_LABEL (gw_applet->cond_pressure), TRUE);
   gtk_label_set_justify (GTK_LABEL (gw_applet->cond_pressure), GTK_JUSTIFY_LEFT);
   gtk_misc_set_alignment (GTK_MISC (gw_applet->cond_pressure), 0, 0.5);
 
@@ -293,6 +375,7 @@ void gweather_dialog_create (GWeatherApplet *gw_applet)
   gtk_table_attach (GTK_TABLE (cond_table), gw_applet->cond_vis, 1, 2, 10, 11,
                     (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                     (GtkAttachOptions) (0), 0, 0);
+  gtk_label_set_selectable (GTK_LABEL (gw_applet->cond_vis), TRUE);
   gtk_label_set_justify (GTK_LABEL (gw_applet->cond_vis), GTK_JUSTIFY_LEFT);
   gtk_misc_set_alignment (GTK_MISC (gw_applet->cond_vis), 0, 0.5);
 
@@ -409,6 +492,8 @@ void gweather_dialog_open (GWeatherApplet *gw_applet)
 
 void gweather_dialog_close (GWeatherApplet *gw_applet)
 {
+    gweather_dialog_save_geometry (gw_applet);
+    
     g_return_if_fail(gw_applet->gweather_dialog != NULL);
     gtk_widget_destroy(gw_applet->gweather_dialog);
     gw_applet->gweather_dialog = NULL;
